.. _sdv.sampling.tabular:

Tabular Conditions
===================

.. currentmodule:: sdv.sampling

Condition
~~~~~~~~~

.. autosummary::
   :toctree: api/

   Condition
   Condition.get_column_values
   Condition.get_num_rows
